module RDMSRoles
  def crc_manager?
    has_role?("is_crc_manager")
  end

  def crc_member?
    has_role?("is_crc_member")
  end

  def crc_group_manager?
    has_role?("is_crc_group_manager")
  end

  def crc_group_member?
    has_role?("is_crc_group_member")
  end

  def publication_manager?
    roles.exists?(name: "publication_manager")
  end

  def admin?
    roles.exists?(name: "admin")
  end

  def crc_manager_for?(group_id)
    group = Collection.find(group_id) rescue nil

    return false unless group

    roles.where(name: "#{group.collection_type.title.parameterize(separator: '_')}_manager").any?
  end

  def group_manager_for?(group_id)
    group = Collection.find(group_id) rescue nil

    return false unless group

    roles.where(name: "#{group.collection_type.title.parameterize(separator: '_')}_#{group.id}_manager").any?
  end

  def crc_member_for?(group_id)
    group = Collection.find(group_id) rescue nil

    return false unless group

    roles.where(name: "#{group.collection_type.title.parameterize(separator: '_')}_member").any?
  end

  def group_member_for?(group_id)
    group = Collection.find(group_id) rescue nil

    return false unless group

    roles.where(name: "#{group.collection_type.title.parameterize(separator: '_')}_#{group.id}_member").any?
  end

  private

  def has_role?(role_name)
    roles.exists?({ role_name => true })
  end
end
